@@ -1,8 +1,8 @@
 if {![package vsatisfies [package provide Tcl] 8.2]} {return}
-package ifneeded fileutil 1.14.10 [list source [file join $dir fileutil.tcl]]
+package ifneeded fileutil 1.15 [list source [file join $dir fileutil.tcl]]
 
 if {![package vsatisfies [package provide Tcl] 8.3]} {return}
-package ifneeded fileutil::traverse 0.5 [list source [file join $dir traverse.tcl]]
+package ifneeded fileutil::traverse 0.6 [list source [file join $dir traverse.tcl]]
 
 if {![package vsatisfies [package provide Tcl] 8.4]} {return}
 package ifneeded fileutil::multi     0.1   [list source [file join $dir multi.tcl]]
